"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var enzyme_1 = require("enzyme");
jest.mock('./normalizeInstrumentations', function () { return ({
    default: function (data) { return data; },
}); });
var index_1 = require("./index");
var paymentRequest_fixture_1 = require("./paymentRequest.fixture");
var generator = function (showMethod) {
    if (showMethod === void 0) { showMethod = 'resolve'; }
    var complete = jest.fn();
    var showResponse = showMethod === 'resolve' ? { complete: complete } : 'error';
    var show = jest.fn().mockImplementation(function () { return Promise[showMethod](showResponse); });
    var abort = jest.fn();
    var addEventListener = jest.fn().mockImplementation(function (event) { });
    var onShowFail = jest.fn();
    var PaymentRequest = jest.fn().mockImplementation(function () { return ({
        show: show,
        abort: abort,
        addEventListener: addEventListener,
    }); });
    global.window.PaymentRequest = PaymentRequest;
    var UIComponent = function () { return React.createElement("div", null); };
    var PaymentComponent = index_1.default()(UIComponent);
    var wrapper = enzyme_1.shallow(React.createElement(PaymentComponent, { config: paymentRequest_fixture_1.default(onShowFail), "data-test": true }));
    return {
        complete: complete,
        show: show,
        abort: abort,
        addEventListener: addEventListener,
        onShowFail: onShowFail,
        PaymentRequest: PaymentRequest,
        UIComponent: UIComponent,
        PaymentComponent: PaymentComponent,
        wrapper: wrapper,
    };
};
describe('PaymentRequest', function () {
    describe('given an environment with no support for the API', function () {
        var UIComponent = function () { return React.createElement("div", null); };
        var PaymentComponent = index_1.default()(UIComponent);
        var config = {};
        var wrapper = enzyme_1.shallow(React.createElement(PaymentComponent, { config: config, "data-test": true }));
        it('should render the UI component', function () {
            expect(wrapper.find(UIComponent).length).toBe(1);
        });
        it('should pass to the UI component the custom props', function () {
            expect(wrapper.find(UIComponent).prop('data-test')).toBe(true);
        });
        it('should not pass to the UI component the config prop', function () {
            expect(wrapper.find(UIComponent).prop('config')).toBe(undefined);
        });
        it('should decorate the UI component with "isSupported" = false', function () {
            expect(wrapper.find(UIComponent).prop('isSupported')).toBe(false);
        });
        it('should not decorate the UI component with "show" prop', function () {
            expect(wrapper.find(UIComponent).prop('show')).toBe(undefined);
        });
        it('should not decorate the UI component with "abort" prop', function () {
            expect(wrapper.find(UIComponent).prop('abort')).toBe(undefined);
        });
    });
    describe('given an environment with support for the API', function () {
        it('should render the UI component', function () {
            var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
            expect(wrapper.find(UIComponent).length).toBe(1);
        });
        it('should pass to the UI component the custom props', function () {
            var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
            expect(wrapper.find(UIComponent).prop('data-test')).toBe(true);
        });
        it('should not pass to the UI component the config prop', function () {
            var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
            expect(wrapper.find(UIComponent).prop('config')).toBe(undefined);
        });
        it('should decorate the UI component with "isSupported" = true', function () {
            var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
            expect(wrapper.find(UIComponent).prop('isSupported')).toBe(true);
        });
        describe('when "show" prop is executed', function () {
            describe('PaymentRequest API', function () {
                it('should be executed once', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
                    wrapper.find(UIComponent).prop('show')();
                    expect(PaymentRequest).toHaveBeenCalledTimes(1);
                });
                it('should be executed with config.methodData, config.details, config.options', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent;
                    wrapper.find(UIComponent).prop('show')();
                    expect(PaymentRequest).toHaveBeenCalledWith(paymentRequest_fixture_1.default().methodData, paymentRequest_fixture_1.default().details, paymentRequest_fixture_1.default().options);
                });
            });
            describe('PaymentRequest.addEventListener API', function () {
                it('should be executed twice', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, addEventListener = _a.addEventListener;
                    wrapper.find(UIComponent).prop('show')();
                    expect(addEventListener).toHaveBeenCalledTimes(2);
                });
                it('should add an event on shippingaddresschange', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, addEventListener = _a.addEventListener;
                    wrapper.find(UIComponent).prop('show')();
                    expect(addEventListener).toHaveBeenCalledWith('shippingaddresschange', expect.any(Function));
                });
                it('should add an event on shippingoptionchange', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, addEventListener = _a.addEventListener;
                    wrapper.find(UIComponent).prop('show')();
                    expect(addEventListener).toHaveBeenCalledWith('shippingoptionchange', expect.any(Function));
                });
            });
            describe('PaymentRequest.show API', function () {
                it('should be executed once', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, show = _a.show;
                    wrapper.find(UIComponent).prop('show')();
                    expect(show).toHaveBeenCalledTimes(1);
                });
                it('should be executed without params', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, show = _a.show;
                    wrapper.find(UIComponent).prop('show')();
                    expect(show).toHaveBeenCalledWith();
                });
            });
        });
        describe('when PaymentRequest.show API is resolved', function () {
            describe('PaymentResponse.complete API', function () {
                it('should be executed once', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, complete = _a.complete;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(complete).toHaveBeenCalledTimes(1);
                        });
                    });
                });
                it('should be executed with "success"', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, complete = _a.complete;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(complete).toHaveBeenCalledWith('success');
                        });
                    });
                });
            });
            describe('config.onShowFail', function () {
                it('should not be executed', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, onShowFail = _a.onShowFail;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(onShowFail).toHaveBeenCalledTimes(0);
                        });
                    });
                });
            });
        });
        describe('when PaymentRequest.show API is rejected', function () {
            describe('PaymentResponse.complete API', function () {
                it('should not be executed', function () {
                    var _a = generator('reject'), wrapper = _a.wrapper, UIComponent = _a.UIComponent, complete = _a.complete;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(complete).toHaveBeenCalledTimes(0);
                        });
                    });
                });
            });
            describe('config.onShowFail', function () {
                it('should be executed once', function () {
                    var _a = generator('reject'), wrapper = _a.wrapper, UIComponent = _a.UIComponent, onShowFail = _a.onShowFail;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(onShowFail).toHaveBeenCalledTimes(1);
                        });
                    });
                });
                it('should be executed with error', function () {
                    var _a = generator('reject'), wrapper = _a.wrapper, UIComponent = _a.UIComponent, onShowFail = _a.onShowFail;
                    wrapper.find(UIComponent).prop('show')();
                    return Promise.resolve().then(function () {
                        return Promise.resolve().then(function () {
                            return expect(onShowFail).toHaveBeenCalledWith('error');
                        });
                    });
                });
            });
        });
        describe('when "abort" prop is executed after "show"', function () {
            describe('PaymentRequest.abort API', function () {
                it('should be executed once', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, abort = _a.abort;
                    wrapper.find(UIComponent).prop('show')();
                    wrapper.find(UIComponent).prop('abort')();
                    expect(abort).toHaveBeenCalledTimes(1);
                });
                it('should be executed without params', function () {
                    var _a = generator(), wrapper = _a.wrapper, UIComponent = _a.UIComponent, abort = _a.abort;
                    wrapper.find(UIComponent).prop('show')();
                    wrapper.find(UIComponent).prop('abort')();
                    expect(abort).toHaveBeenCalledWith();
                });
            });
        });
    });
});
//# sourceMappingURL=paymentRequest.test.js.map